pub struct BooleanTest {
pub column: Option<String>,
}Expand description
A test that uses an alerting result in a boolean column produced by the SQL query.
This type is not used in any activity, and only used as part of another schema.
Fields
column: Option<String>Required. The name of the column containing the boolean value. If the value in a row is NULL, that row is ignored.