pub struct RowCountTest {
pub comparison: Option<String>,
pub threshold: Option<i64>,
}Expand description
A test that checks if the number of rows in the result set violates some threshold.
This type is not used in any activity, and only used as part of another schema.
Fields
comparison: Option<String>Required. The comparison to apply between the number of rows returned by the query and the threshold.
threshold: Option<i64>Required. The value against which to compare the row count.